@@ -1,12 +1,12 @@
 /*
- * Copyright © 2011 Christian Persch
+ * Copyright © 2011, 2012, 2013 Christian Persch
  *
- * Gnome-terminal is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Gnome-terminal is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -31,10 +31,12 @@
 #include "terminal-type-builtins.h"
 
 static gboolean dry_run = FALSE;
+static gboolean force = FALSE;
 static gboolean verbose = FALSE;
 
 static const GOptionEntry options[] = {
   { "dry-run", 0, 0, G_OPTION_ARG_NONE, &dry_run, NULL, NULL },
+  { "force", 0, 0, G_OPTION_ARG_NONE, &force, NULL, NULL },
   { "verbose", 0, 0, G_OPTION_ARG_NONE, &verbose, NULL, NULL },
   { NULL }
 };
@@ -280,12 +282,11 @@ migrate_genum (GConfClient *client,
 }
 
 static gboolean
-migrate_global_prefs (GError **error)
+migrate_global_prefs (GSettings *settings,
+                      GError **error)
 {
   GConfClient *client;
-  GSettings *settings;
 
-  settings = g_settings_new (TERMINAL_SETTING_SCHEMA);
   client = gconf_client_get_default ();
 
   migrate_bool (client, GCONF_GLOBAL_PREFIX, "confirm_window_close",
@@ -300,7 +301,6 @@ migrate_global_prefs (GError **error)
   migrate_string_list (client, GCONF_GLOBAL_PREFIX, "active_encodings",
                        settings, TERMINAL_SETTING_ENCODINGS_KEY);
 
-  g_object_unref (settings);
   g_object_unref (client);
 
   return TRUE;
@@ -323,7 +323,8 @@ migrate_profile (GConfClient *client,
 
   path = g_strdup_printf (TERMINAL_PROFILES_PATH_PREFIX ":%s/", str);
   if (verbose)
-    g_print ("Migrating profile \"%s\" to \"%s\"\n", gconf_id, path);
+    g_printerr ("Migrating profile \"%s\" to \"%s\" is-default %s\n",
+                gconf_id, path, is_default ? "true" : "false");
 
   settings = g_settings_new_with_path (TERMINAL_PROFILE_SCHEMA, path);
   g_free (path);
@@ -422,23 +423,21 @@ migrate_profile (GConfClient *client,
   g_free (path);
   g_object_unref (settings);
 
-  if (is_default)
-    g_settings_set_string (global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY, str);
-
   return g_strdup (str);
 }
 
 static gboolean
-migrate_profiles (GError **error)
+migrate_profiles (GSettings *global_settings,
+                  GError **error)
 {
-  GSettings *global_settings;
   GConfClient *client;
   GConfValue *value, *dvalue;
   GSList *l;
   GPtrArray *profile_uuids;
-  const char *profile, *default_profile;
+  char *uuid;
+  const char *profile, *default_profile, *default_uuid;
+  gboolean is_default;
 
-  global_settings = g_settings_new (TERMINAL_SETTING_SCHEMA);
   client = gconf_client_get_default ();
 
   profile_uuids = g_ptr_array_new_with_free_func ((GDestroyNotify) g_free);
@@ -450,6 +449,7 @@ migrate_profiles (GError **error)
   else
     default_profile = NULL;
 
+  default_uuid = NULL;
   value = gconf_client_get (client, GCONF_GLOBAL_PREFIX "/profile_list", NULL);
   if (value != NULL &&
       value->type == GCONF_VALUE_LIST &&
@@ -457,11 +457,11 @@ migrate_profiles (GError **error)
     for (l = gconf_value_get_list (value); l != NULL; l = l->next) {
       profile = gconf_value_get_string (l->data);
 
-      g_ptr_array_add (profile_uuids,
-                       migrate_profile (client, 
-                                        global_settings,
-                                        profile, 
-                                        g_strcmp0 (profile, default_profile) == 0));
+      is_default = g_strcmp0 (profile, default_profile) == 0;
+      uuid = migrate_profile (client, global_settings, profile, is_default);
+      g_ptr_array_add (profile_uuids, uuid);
+      if (is_default)
+        default_uuid = uuid;
     }
   }
 
@@ -485,6 +485,14 @@ migrate_profiles (GError **error)
     g_ptr_array_add (profile_uuids, NULL);
     g_settings_set_strv (global_settings, TERMINAL_SETTING_PROFILES_KEY,
                          (const char * const *) profile_uuids->pdata);
+
+    /* The GConf setting might be corrupt, with the default profile pointing to a profile
+     * that doesn't actually exist. In this case, just pick the first profile as default.
+     */
+    if (default_uuid == NULL)
+      default_uuid = (const char *) profile_uuids->pdata[0];
+
+    g_settings_set_string (global_settings, TERMINAL_SETTING_DEFAULT_PROFILE_KEY, default_uuid);
   }
 
   if (value)
@@ -492,7 +500,6 @@ migrate_profiles (GError **error)
   if (dvalue)
     gconf_value_free (dvalue);
   g_object_unref (client);
-  g_object_unref (global_settings);
   g_ptr_array_free (profile_uuids, TRUE);
 
   return TRUE;
@@ -501,91 +508,77 @@ migrate_profiles (GError **error)
 static gboolean
 migrate_accels (GError **error)
 {
-  static const struct { const char *key; const char *path; } data[] = {
-    { "new_tab", "FileNewTab" },
-    { "new_window", "FileNewWindow" },
-    { "new_profile", "FileNewProfile" },
-    { "close_tab", "FileCloseTab" },
-    { "close_window", "FileCloseWindow"},
-    { "copy", "EditCopy" },
-    { "paste", "EditPaste" },
-    { "toggle_menubar", "ViewMenubar" },
-    { "full_screen", "ViewFullscreen" },
-    { "zoom_in", "ViewZoomIn" },
-    { "zoom_out", "ViewZoomOut" },
-    { "zoom_normal", "ViewZoom100" },
-    { "set_window_title", "TerminalSetTitle" },
-    { "reset", "TerminalReset" },
-    { "reset_and_clear", "TerminalResetClear" },
-    { "prev_tab", "TabsPrevious" },
-    { "next_tab", "TabsNext" },
-    { "move_tab_left", "TabsMoveLeft" },
-    { "move_tab_right", "TabsMoveRight" },
-    { "detach_tab", "TabsDetach" },
-    { "switch_to_tab_1", "TabsSwitch1" },
-    { "switch_to_tab_2", "TabsSwitch2" },
-    { "switch_to_tab_3", "TabsSwitch3" },
-    { "switch_to_tab_4", "TabsSwitch4" },
-    { "switch_to_tab_5", "TabsSwitch5" },
-    { "switch_to_tab_6", "TabsSwitch6" },
-    { "switch_to_tab_7", "TabsSwitch7" },
-    { "switch_to_tab_8", "TabsSwitch8" },
-    { "switch_to_tab_9", "TabsSwitch9" },
-    { "switch_to_tab_10", "TabsSwitch10" },
-    { "switch_to_tab_11", "TabsSwitch11" },
-    { "switch_to_tab_12", "TabsSwitch12" },
-    { "help", "HelpContents" }
+  static const const struct { const char *gconf_key; const char *settings_key; } const data[] = {
+    { "new_tab",          "new-tab"            },
+    { "new_window",       "new-window"         },
+    { "new_profile",      "new-profile"        },
+    { "close_tab",        "close-tab"          },
+    { "close_window",     "close-window"       },
+    { "copy",             "copy"               },
+    { "paste",            "paste"              },
+    { "toggle_menubar",   "toggle-menubar"     },
+    { "full_screen",      "full-screen"        },
+    { "zoom_in",          "zoom-in"            },
+    { "zoom_out",         "zoom-out"           },
+    { "zoom_normal",      "zoom-normal"        },
+    { "set_window_title", "set-terminal-title" },
+    { "reset",            "reset"              },
+    { "reset_and_clear",  "reset-and-clear"    },
+    { "prev_tab",         "prev-tab"           },
+    { "next_tab",         "next-tab"           },
+    { "move_tab_left",    "move-tab-left"      },
+    { "move_tab_right",   "move-tab-right"     },
+    { "detach_tab",       "detach-tab"         },
+    { "switch_to_tab_1",  "switch-to-tab-1"    },
+    { "switch_to_tab_2",  "switch-to-tab-2"    },
+    { "switch_to_tab_3",  "switch-to-tab-3"    },
+    { "switch_to_tab_4",  "switch-to-tab-4"    },
+    { "switch_to_tab_5",  "switch-to-tab-5"    },
+    { "switch_to_tab_6",  "switch-to-tab-6"    },
+    { "switch_to_tab_7",  "switch-to-tab-7"    },
+    { "switch_to_tab_8",  "switch-to-tab-8"    },
+    { "switch_to_tab_9",  "switch-to-tab-9"    },
+    { "switch_to_tab_10", "switch-to-tab-10"   },
+    { "switch_to_tab_11", "switch-to-tab-11"   },
+    { "switch_to_tab_12", "switch-to-tab-12"   },
+    { "help",             "help"               }
   };
   GConfClient *client;
+  GSettings *settings;
   guint i;
-  char *key, *path;
+  char *gconf_path;
   GConfValue *value;
-  GString *str;
 
   client = gconf_client_get_default ();
-  str = g_string_sized_new (1024);
+  settings = g_settings_new (TERMINAL_KEYBINDINGS_SCHEMA);
 
   for (i = 0; i < G_N_ELEMENTS (data); ++i) {
-    key = g_strdup_printf ("/apps/gnome-terminal/keybindings/%s", data[i].key);
-    path = g_strdup_printf ("<Actions>/Main/%s", data[i].path);
+    gconf_path = g_strdup_printf ("/apps/gnome-terminal/keybindings/%s", data[i].gconf_key);
 
-    if ((value = gconf_client_get_without_default (client, key, NULL)) != NULL &&
-        value->type == GCONF_VALUE_STRING)
-      g_string_append_printf (str,
-                              "(gtk_accel_path \"%s\" \"%s\")\n",
-                              path, gconf_value_get_string (value));
+    value = gconf_client_get_without_default (client, gconf_path, NULL);
+    g_free (gconf_path);
+    if (value == NULL)
+      continue;
 
-    g_free (key);
-    g_free (path);
-    if (value)
-      gconf_value_free (value);
+    if (value->type == GCONF_VALUE_STRING)
+      g_settings_set_string (settings, data[i].settings_key, gconf_value_get_string (value));
+
+    gconf_value_free (value);
   }
 
-  path = g_build_filename (g_get_user_config_dir (),
-                           "gnome-terminal",
-                           NULL);
-  g_mkdir_with_parents (path, 0700);
-  g_free (path);
-
-  path = g_build_filename (g_get_user_config_dir (),
-                           "gnome-terminal",
-                           "accels",
-                           NULL);
-  g_file_set_contents (path, str->str, str->len, NULL);
-  g_free (path);
-
-  g_string_free (str, TRUE);
+  g_object_unref (settings);
   g_object_unref (client);
 
   return TRUE;
 }
 
 static gboolean
-migrate (GError **error)
+migrate (GSettings *global_settings,
+         GError **error)
 {
-  return migrate_global_prefs (error) &&
-         migrate_profiles (error) &&
-         migrate_accels (error);
+  return migrate_global_prefs (global_settings, error) &&
+    migrate_profiles (global_settings, error) &&
+    migrate_accels (error);
 }
 
 static void
@@ -607,6 +600,7 @@ main (int argc,
 {
   GOptionContext *context;
   GError *error = NULL;
+  GSettings *global_settings;
 
   setlocale (LC_ALL, "");
 
@@ -625,10 +619,19 @@ main (int argc,
   }
   g_option_context_free (context);
 
-  if (!migrate (&error)) {
+  global_settings = g_settings_new (TERMINAL_SETTING_SCHEMA);
+
+  if (g_settings_get_uint (global_settings, TERMINAL_SETTING_SCHEMA_VERSION) >= TERMINAL_SCHEMA_VERSION) {
+    if (verbose)
+      g_printerr ("Already migrated.\n");
+    if (!force)
+      goto out;
+  }
+
+  if (!migrate (global_settings, &error)) {
     g_printerr ("Error: %s\n", error->message);
     g_error_free (error);
-    return EXIT_FAILURE;
+    goto out;
   }
 
   update_schema_version ();
@@ -641,5 +644,8 @@ main (int argc,
   if (verbose)
     g_printerr ("Migration successful!\n");
 
+ out:
+  g_object_unref (global_settings);
+
   return EXIT_SUCCESS;
 }
