@@ -5,12 +5,12 @@
  * Copyright © 2003 Mariano Suarez-Alvarez
  * Copyright © 2008, 2010, 2011 Christian Persch
  *
- * Gnome-terminal is free software; you can redistribute it and/or modify
+ * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 3 of the License, or
+ * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Gnome-terminal is distributed in the hope that it will be useful,
+ * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
@@ -1043,17 +1043,16 @@ terminal_app_manage_profiles (TerminalApp     *app,
       return;
     }
 
-  if (!terminal_util_load_builder_resource ("/org/gnome/terminal/ui/profile-manager.ui",
-                                            "profile-manager", &dialog,
-                                            "profiles-treeview-container", &tree_view_container,
-                                            "new-profile-button", &new_button,
-                                            "edit-profile-button", &edit_button,
-                                            "clone-profile-button", &clone_button,
-                                            "delete-profile-button", &remove_button,
-                                            "default-profile-hbox", &default_hbox,
-                                            "default-profile-label", &default_label,
-                                            NULL))
-    return;
+  terminal_util_load_builder_resource ("/org/gnome/terminal/ui/profile-manager.ui",
+                                       "profile-manager", &dialog,
+                                       "profiles-treeview-container", &tree_view_container,
+                                       "new-profile-button", &new_button,
+                                       "edit-profile-button", &edit_button,
+                                       "clone-profile-button", &clone_button,
+                                       "delete-profile-button", &remove_button,
+                                       "default-profile-hbox", &default_hbox,
+                                       "default-profile-label", &default_label,
+                                       NULL);
 
   app->manage_profiles_dialog = GTK_WIDGET (dialog);
   app->manage_profiles_new_button = GTK_WIDGET (new_button);
